#!/usr/bin/env python
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

import optparse
from proton.handlers import MessagingHandler
from proton.reactor import Container

class Recv(MessagingHandler):
    def __init__(self, url, count):
        super(Recv, self).__init__(prefetch=0)
        self.url = url
        self.expected = count
        self.received = 0
        self.batch_size = 10

    def on_start(self, event):
        event.container.create_receiver(self.url)

    def request_batch(self, receiver):
        self.batch_start = self.received
        receiver.flow(self.batch_size)

    def on_link_opened(self, event):
        self.request_batch(event.receiver)
        event.receiver.drain_mode = True

    def check_empty(self, receiver):
        if receiver.drain_mode and not receiver.credit and not receiver.queued:
            if self.received < self.batch_start + self.batch_size:
                print "Queue is empty, exiting"
                receiver.close()
                receiver.connection.close()
            else:
                self.request_batch(receiver)

    def on_link_flow(self, event):
        self.check_empty(event.receiver)

    def on_message(self, event):
        if self.expected == 0 or self.received < self.expected:
            print event.message.body
            self.received += 1
            if self.received == self.expected:
                event.receiver.close()
                event.connection.close()
        self.check_empty(event.receiver)


parser = optparse.OptionParser(usage="usage: %prog [options]")
parser.add_option("-a", "--address", default="localhost:5672/examples",
                  help="address from which messages are received (default %default)")
parser.add_option("-m", "--messages", type="int", default=0,
                  help="number of messages to receive; 0 receives indefinitely (default %default)")
opts, args = parser.parse_args()

try:
    Container(Recv(opts.address, opts.messages)).run()
except KeyboardInterrupt: pass



